@@ -14,7 +14,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = 'v5.224';
+our $VERSION = 'v5.26';
 
 URPM->bootstrap($VERSION);
 
@@ -293,7 +293,7 @@ URPM - Manipulate RPM files and headers
     });
 
     # loading and parsing a synthesis file
-    my $urpm = URPM->new;
+    my $urpm = new URPM;
     $urpm->parse_synthesis("synthesis.sample.cz");
     $urpm->traverse(sub {
 	# retrieve all packages from the dependency list
@@ -353,9 +353,6 @@ Force the re-reading of the RPM configuration files.
 $urpm->{depslist} is loaded when parsing sources (synthesis, hdlists or a plain
 rpm file).
 
-Synthesis and hdlists files are generated by L<genhdlist2> or L<gendistrib> (a
-gendhlist2 wrapper handling a whole media set) from L<rpmtools> package.
-
 =over
 
 =item $urpm->parse_synthesis($file [, callback => sub {...} ])
